@@ -17,30 +17,33 @@ TAG_CLONE = "clone"
 TAG_MASTER = "master"
 ALL_TAGS = [TAG_CLONE, TAG_MASTER]
 
+
 def is_clone(resource_el):
     return resource_el.tag == TAG_CLONE
 
+
 def is_master(resource_el):
     return resource_el.tag == TAG_MASTER
 
+
 def is_any_clone(resource_el):
     return resource_el.tag in ALL_TAGS
 
+
 def is_promotable_clone(resource_el):
     """
     Return True if resource_el is a promotable clone, False on clone and master
     """
-    return (
-        is_clone(resource_el)
-        and
-        is_true(nvpair.get_value(
+    return is_clone(resource_el) and is_true(
+        nvpair.get_value(
             nvpair.META_ATTRIBUTES_TAG,
             resource_el,
             "promotable",
             default="false",
-        ))
+        )
     )
 
+
 def get_parent_any_clone(resource_el):
     """
     Get any parent clone of a primitive (may be in a group) or group
@@ -57,6 +60,7 @@ def get_parent_any_clone(resource_el):
         element = parent_el
     return None
 
+
 def append_new(resources_section, id_provider, primitive_element, options):
     """
     Append a new clone element (containing the primitive_element) to the
@@ -72,7 +76,7 @@ def append_new(resources_section, id_provider, primitive_element, options):
         TAG_CLONE,
         id=id_provider.allocate_id(
             "{0}-{1}".format(primitive_element.get("id"), TAG_CLONE)
-        )
+        ),
     )
     clone_element.append(primitive_element)
 
@@ -81,5 +85,6 @@ def append_new(resources_section, id_provider, primitive_element, options):
 
     return clone_element
 
+
 def get_inner_resource(clone_el):
     return clone_el.xpath("./primitive | ./group")[0]
