@@ -1,14 +1,18 @@
 from collections import namedtuple
 from typing import (
     cast,
+    Iterable,
+    List,
     Optional,
-    Sequence,
+    Set,
+    Tuple,
 )
 from xml.etree.ElementTree import Element
 
 from lxml.etree import _Element
 
-from pcs.lib import reports
+from pcs.common import reports
+from pcs.common.reports.item import ReportItem, ReportItemList
 from pcs.lib.cib import nvpair
 from pcs.lib.cib.resource.bundle import (
     TAG as TAG_BUNDLE,
@@ -36,22 +40,35 @@ from pcs.lib.cib.tools import ElementSearcher
 from pcs.lib.xml_tools import find_parent
 
 
+ALL_RESOURCE_XML_TAGS = sorted(
+    TAG_CLONE_ALL + [TAG_GROUP, TAG_PRIMITIVE, TAG_BUNDLE]
+)
+
+
 def are_meta_disabled(meta_attributes):
     return meta_attributes.get("target-role", "Started").lower() == "stopped"
 
+
 def _can_be_evaluated_as_positive_num(value):
     string_wo_leading_zeros = str(value).lstrip("0")
     return string_wo_leading_zeros and string_wo_leading_zeros[0].isdigit()
 
+
 def is_clone_deactivated_by_meta(meta_attributes):
-    return are_meta_disabled(meta_attributes) or any([
-        not _can_be_evaluated_as_positive_num(meta_attributes.get(key, "1"))
-        for key in ["clone-max", "clone-node-max"]
-    ])
+    return are_meta_disabled(meta_attributes) or any(
+        [
+            not _can_be_evaluated_as_positive_num(meta_attributes.get(key, "1"))
+            for key in ["clone-max", "clone-node-max"]
+        ]
+    )
+
 
 def find_one_resource_and_report(
-    context_element, resource_id, report_list, additional_search=None,
-    resource_tags=None
+    context_element,
+    resource_id,
+    report_list,
+    additional_search=None,
+    resource_tags=None,
 ):
     """
     Find a single resource or return None if not found, report errors
@@ -71,9 +88,13 @@ def find_one_resource_and_report(
     )
     return resource_el_list[0] if resource_el_list else None
 
+
 def find_resources_and_report(
-    context_element, resource_ids, report_list, additional_search=None,
-    resource_tags=None
+    context_element,
+    resource_ids,
+    report_list,
+    additional_search=None,
+    resource_tags=None,
 ):
     """
     Find a list of resource, report errors
@@ -87,8 +108,7 @@ def find_resources_and_report(
     if not additional_search:
         additional_search = lambda x: [x]
     if resource_tags is None:
-        resource_tags = TAG_CLONE_ALL + [TAG_GROUP, TAG_PRIMITIVE, TAG_BUNDLE]
-
+        resource_tags = ALL_RESOURCE_XML_TAGS
     resource_el_list = []
     for res_id in resource_ids:
         searcher = ElementSearcher(resource_tags, res_id, context_element)
@@ -98,7 +118,76 @@ def find_resources_and_report(
             report_list.extend(searcher.get_errors())
     return resource_el_list
 
-def find_primitives(resource_el):
+
+def expand_tags_to_resources(
+    resources_section: Element, resource_or_tag_el_list: Iterable[Element],
+) -> List[Element]:
+    """
+    Substitute tag elements in the given list with resource elements which tags
+    refer to.
+
+    resources_section -- element resources of a cib tree
+    resource_or_tag_el_list -- element list which contains tag or resource
+        elements
+    """
+    only_resources_set = set()
+    for el in resource_or_tag_el_list:
+        if el.tag == "tag":
+            for _id in [
+                obj_ref.get("id", "") for obj_ref in el.findall("obj_ref")
+            ]:
+                searcher = ElementSearcher(
+                    ALL_RESOURCE_XML_TAGS, _id, resources_section,
+                )
+                if searcher.element_found():
+                    only_resources_set.add(searcher.get_element())
+        else:
+            only_resources_set.add(el)
+    return list(only_resources_set)
+
+
+def find_resources_or_tags(
+    cib: Element, id_list: Iterable[str],
+) -> Tuple[List[Element], ReportItemList]:
+    """
+    Find resource elements by using resource or tag ids.
+
+    cib -- cib element
+    id_list -- resource or tag ids
+    """
+    resource_or_tag_el_list = []
+    not_found_id_list: List[str] = []
+    for _id in set(id_list):
+        xpath_result = cast(_Element, cib).xpath(
+            """
+            /cib/configuration/resources//*[{resource_tags}][@id="{_id}"]
+            |
+            /cib/configuration/tags/tag[@id="{_id}"]
+            """.format(
+                _id=_id,
+                resource_tags=" or ".join(
+                    f"self::{tag}" for tag in ALL_RESOURCE_XML_TAGS
+                ),
+            )
+        )
+        if xpath_result:
+            resource_or_tag_el_list.append(cast(List[Element], xpath_result)[0])
+        else:
+            not_found_id_list.append(_id)
+
+    report_list: ReportItemList = []
+    for _id in sorted(not_found_id_list):
+        report_list.append(
+            ReportItem.error(
+                reports.messages.IdNotFound(
+                    _id, sorted(ALL_RESOURCE_XML_TAGS + ["tag"]),
+                ),
+            ),
+        )
+    return resource_or_tag_el_list, report_list
+
+
+def find_primitives(resource_el: Element) -> List[Element]:
     """
     Get list of primitives contained in a given resource
     etree resource_el -- resource element
@@ -114,7 +203,25 @@ def find_primitives(resource_el):
         return [resource_el]
     return []
 
-def get_inner_resources(resource_el: Element) -> Sequence[Element]:
+
+def get_all_inner_resources(resource_el: Element) -> Set[Element]:
+    """
+    Return all inner resources (both direct and indirect) of a resource
+    Example: for a clone containing a group, this function will return both
+    the group and the resources inside the group
+
+    resource_el -- resource element to get its inner resources
+    """
+    all_inner: Set[Element] = set()
+    to_process = set([resource_el])
+    while to_process:
+        new_inner = get_inner_resources(to_process.pop())
+        to_process.update(set(new_inner) - all_inner)
+        all_inner.update(new_inner)
+    return all_inner
+
+
+def get_inner_resources(resource_el: Element) -> List[Element]:
     """
     Return list of inner resources (direct descendants) of a resource
     specified as resource_el.
@@ -132,6 +239,7 @@ def get_inner_resources(resource_el: Element) -> Sequence[Element]:
         return get_group_inner_resources(resource_el)
     return []
 
+
 def is_wrapper_resource(resource_el: Element) -> bool:
     """
     Return True for resource_el of types that can contain other resource(s)
@@ -141,12 +249,11 @@ def is_wrapper_resource(resource_el: Element) -> bool:
     """
     return (
         is_group(resource_el)
-        or
-        is_bundle(resource_el)
-        or
-        is_any_clone(resource_el)
+        or is_bundle(resource_el)
+        or is_any_clone(resource_el)
     )
 
+
 def get_parent_resource(resource_el: Element) -> Optional[Element]:
     """
     Return a direct ancestor of a specified resource or None if the resource
@@ -161,6 +268,7 @@ def get_parent_resource(resource_el: Element) -> Optional[Element]:
         return parent_el
     return None
 
+
 def find_resources_to_enable(resource_el):
     """
     Get resources to enable in order to enable specified resource succesfully
@@ -182,32 +290,27 @@ def find_resources_to_enable(resource_el):
         to_enable.append(parent)
     return to_enable
 
+
 def enable(resource_el, id_provider):
     """
     Enable specified resource
     etree resource_el -- resource element
     """
     nvpair.arrange_first_meta_attributes(
-        resource_el,
-        {
-            "target-role": "",
-        },
-        id_provider
+        resource_el, {"target-role": "",}, id_provider
     )
 
+
 def disable(resource_el, id_provider):
     """
     Disable specified resource
     etree resource_el -- resource element
     """
     nvpair.arrange_first_meta_attributes(
-        resource_el,
-        {
-            "target-role": "Stopped",
-        },
-        id_provider
+        resource_el, {"target-role": "Stopped",}, id_provider
     )
 
+
 def find_resources_to_manage(resource_el):
     """
     Get resources to manage to manage the specified resource succesfully
@@ -222,7 +325,7 @@ def find_resources_to_manage(resource_el):
     # and vice versa.
     res_id = resource_el.attrib["id"]
     return (
-        [resource_el] # the resource itself
+        [resource_el]  # the resource itself
         +
         # its parents
         find_parent(resource_el, "resources").xpath(
@@ -239,14 +342,16 @@ def find_resources_to_manage(resource_el):
                 //group[primitive[@id='{r}']]
                 |
                 ./bundle[primitive[@id='{r}']]
-            """
-            .format(r=res_id)
+            """.format(
+                r=res_id
+            )
         )
         +
         # its children
         resource_el.xpath("(./group|./primitive|./group/primitive)")
     )
 
+
 def find_resources_to_unmanage(resource_el):
     """
     Get resources to unmanage to unmanage the specified resource succesfully
@@ -301,32 +406,63 @@ def find_resources_to_unmanage(resource_el):
         return [resource_el]
     return []
 
+
 def manage(resource_el, id_provider):
     """
     Set the resource to be managed by the cluster
     etree resource_el -- resource element
     """
     nvpair.arrange_first_meta_attributes(
-        resource_el,
-        {
-            "is-managed": "",
-        },
-        id_provider
+        resource_el, {"is-managed": "",}, id_provider
     )
 
+
 def unmanage(resource_el, id_provider):
     """
     Set the resource not to be managed by the cluster
     etree resource_el -- resource element
     """
     nvpair.arrange_first_meta_attributes(
-        resource_el,
-        {
-            "is-managed": "false",
-        },
-        id_provider
+        resource_el, {"is-managed": "false",}, id_provider
     )
 
+
+def find_resources_to_delete(resource_el: Element) -> List[Element]:
+    """
+    Get resources to delete, children and parents of the given resource if
+    necessary.
+
+    If element is a primitive which is in a clone and you specify one of them,
+    you will get elements for both of them. If you specify group element which
+    is in a clone then will you get clone, group, and all primitive elements in
+    a group and etc.
+
+    resource_el - resource element (bundle, clone, group, primitive)
+    """
+    result = [resource_el]
+    # childrens of bundle, clone, group, clone-with-group
+    inner_resource_list = get_inner_resources(resource_el)
+    if inner_resource_list:
+        result.extend(inner_resource_list)
+        inner_resource = inner_resource_list[0]
+        if is_group(inner_resource):
+            result.extend(get_inner_resources(inner_resource))
+    # parents of primitive if needed (group, clone)
+    parent_el = get_parent_resource(resource_el)
+    if parent_el is None or is_bundle(parent_el):
+        return result
+    if is_any_clone(parent_el):
+        result.insert(0, parent_el)
+    if is_group(parent_el):
+        group_inner_resources = get_group_inner_resources(parent_el)
+        if len(group_inner_resources) <= 1:
+            result = [parent_el] + group_inner_resources
+            clone_el = get_parent_resource(parent_el)
+            if clone_el is not None:
+                result.insert(0, clone_el)
+    return result
+
+
 def validate_move(resource_element, master):
     """
     Validate moving a resource to a node
@@ -339,45 +475,53 @@ def validate_move(resource_element, master):
 
     if analysis.is_bundle:
         report_list.append(
-            reports.cannot_move_resource_bundle(resource_element.get("id"))
+            ReportItem.error(
+                reports.messages.CannotMoveResourceBundle(
+                    resource_element.get("id")
+                )
+            )
         )
         return report_list
 
-    if (
-        (analysis.is_clone or analysis.is_in_clone)
-        and not
-        (analysis.is_promotable_clone or analysis.is_in_promotable_clone)
+    if (analysis.is_clone or analysis.is_in_clone) and not (
+        analysis.is_promotable_clone or analysis.is_in_promotable_clone
     ):
         report_list.append(
-            reports.cannot_move_resource_clone(resource_element.get("id"))
+            ReportItem.error(
+                reports.messages.CannotMoveResourceClone(
+                    resource_element.get("id")
+                )
+            )
         )
         return report_list
 
-    if (
-        not master
-        and
-        (analysis.is_promotable_clone or analysis.is_in_promotable_clone)
+    if not master and (
+        analysis.is_promotable_clone or analysis.is_in_promotable_clone
     ):
         # We assume users want to move master role. Still we require them to
         # actually specify that. 1) To be consistent with command for bannig
         # resources. 2) To prevent users from accidentally move slave role.
         # This check can be removed if someone requests it.
         report_list.append(
-            reports.cannot_move_resource_promotable_not_master(
-                resource_element.get("id"),
-                analysis.promotable_clone_id
+            ReportItem.error(
+                reports.messages.CannotMoveResourcePromotableNotMaster(
+                    resource_element.get("id"), analysis.promotable_clone_id,
+                )
             )
         )
     elif master and not analysis.is_promotable_clone:
         report_list.append(
-            reports.cannot_move_resource_master_resource_not_promotable(
-                resource_element.get("id"),
-                promotable_id=analysis.promotable_clone_id
+            ReportItem.error(
+                reports.messages.CannotMoveResourceMasterResourceNotPromotable(
+                    resource_element.get("id"),
+                    promotable_id=analysis.promotable_clone_id,
+                )
             )
         )
 
     return report_list
 
+
 def validate_ban(resource_element, master):
     """
     Validate banning a resource on a node
@@ -390,14 +534,17 @@ def validate_ban(resource_element, master):
 
     if master and not analysis.is_promotable_clone:
         report_list.append(
-            reports.cannot_ban_resource_master_resource_not_promotable(
-                resource_element.get("id"),
-                promotable_id=analysis.promotable_clone_id
+            ReportItem.error(
+                reports.messages.CannotBanResourceMasterResourceNotPromotable(
+                    resource_element.get("id"),
+                    promotable_id=analysis.promotable_clone_id,
+                )
             )
         )
 
     return report_list
 
+
 def validate_unmove_unban(resource_element, master):
     """
     Validate unmoving/unbanning a resource to/on nodes
@@ -409,15 +556,19 @@ def validate_unmove_unban(resource_element, master):
     analysis = _validate_move_ban_clear_analyzer(resource_element)
 
     if master and not analysis.is_promotable_clone:
+        # pylint: disable=line-too-long
         report_list.append(
-            reports.cannot_unmove_unban_resource_master_resource_not_promotable(
-                resource_element.get("id"),
-                promotable_id=analysis.promotable_clone_id
+            ReportItem.error(
+                reports.messages.CannotUnmoveUnbanResourceMasterResourceNotPromotable(
+                    resource_element.get("id"),
+                    promotable_id=analysis.promotable_clone_id,
+                )
             )
         )
 
     return report_list
 
+
 class _MoveBanClearAnalysis(
     namedtuple(
         "_MoveBanClearAnalysis",
@@ -428,11 +579,12 @@ class _MoveBanClearAnalysis(
             "is_promotable_clone",
             "is_in_promotable_clone",
             "promotable_clone_id",
-        ]
+        ],
     )
 ):
     pass
 
+
 def _validate_move_ban_clear_analyzer(resource_element):
     resource_is_bundle = False
     resource_is_clone = False
@@ -464,5 +616,5 @@ def _validate_move_ban_clear_analyzer(resource_element):
             promotable_clone_element.get("id")
             if promotable_clone_element is not None
             else None
-        )
+        ),
     )
