@@ -1,7 +1,10 @@
 import re
+from xml.etree.ElementTree import Element
 
+from pcs.common import reports
+from pcs.common.reports import codes as report_codes
+from pcs.common.reports.item import ReportItem
 from pcs.common.tools import Version
-from pcs.lib import reports
 from pcs.lib.cib import sections
 from pcs.lib.errors import LibraryError
 from pcs.lib.pacemaker.values import (
@@ -12,10 +15,12 @@ from pcs.lib.xml_tools import get_root, get_sub_element
 
 VERSION_FORMAT = r"(?P<major>\d+)\.(?P<minor>\d+)(\.(?P<rev>\d+))?$"
 
+
 class IdProvider:
     """
     Book ids for future use in the CIB and generate new ids accordingly
     """
+
     def __init__(self, cib_element):
         """
         etree cib_element -- any element of the xml to being check against
@@ -43,13 +48,141 @@ class IdProvider:
             if _id in reported_ids:
                 continue
             if _id in self._booked_ids or does_id_exist(self._cib, _id):
-                report_list.append(reports.id_already_exists(_id))
+                report_list.append(
+                    ReportItem.error(reports.messages.IdAlreadyExists(_id))
+                )
                 reported_ids.add(_id)
                 continue
             self._booked_ids.add(_id)
         return report_list
 
 
+class ElementSearcher:
+    """
+    Search for an element, allow to book its id if not found, provide reports
+
+    Usage:
+    es = ElementSearcher(element_tag, element_id, context_element)
+    if es.element_found():
+        # the element has been found
+        element = es.get_element()
+    # if you want to create the element when it does not exist
+    elif es.validate_book_id(id_provider)
+        element = Element(element_id)
+    else:
+        raise LibraryError(es.get_errors())
+    """
+
+    def __init__(
+        self, tags, element_id, context_element, element_type_desc=None
+    ):
+        """
+        string|iterable tags -- a tag (string) or tags (iterable) to look for
+        string element_id -- an id to look for
+        etree.Element context_element -- an element to look in
+        string|iterable element_type_desc -- element types for reports, tags
+            if not specified
+        """
+        self._executed = False
+        self._element = None
+        self._element_id = element_id
+        self._context_element = context_element
+        self._tag_list = [tags] if isinstance(tags, str) else tags
+        self._expected_types = self._prepare_expected_types(element_type_desc)
+        self._book_errors = None
+
+    def _prepare_expected_types(self, element_type_desc):
+        if element_type_desc is None:
+            return self._tag_list
+        if isinstance(element_type_desc, str):
+            return [element_type_desc]
+        return element_type_desc
+
+    def element_found(self):
+        if not self._executed:
+            self._execute()
+        return self._element is not None
+
+    def get_element(self):
+        if not self._executed:
+            self._execute()
+        return self._element
+
+    def validate_book_id(self, id_provider, id_description="id"):
+        """
+        Book element_id in the id_provider, return True if success
+        """
+        self._book_errors = []
+        validate_id(
+            self._element_id,
+            description=id_description,
+            reporter=self._book_errors,
+        )
+        if not self._book_errors:
+            self._book_errors += id_provider.book_ids(self._element_id)
+        return len(self._book_errors) < 1
+
+    def get_errors(self):
+        """
+        Report why the element has not been found or booking its id failed
+        """
+        if self.element_found() or (
+            self._book_errors is not None and not self._book_errors
+        ):
+            raise AssertionError(
+                "Improper usage: cannot report errors when there are none"
+            )
+
+        element = get_root(self._context_element).find(
+            f'.//*[@id="{self._element_id}"]'
+        )
+
+        if element is not None:
+            if element.tag in self._tag_list:
+                return [
+                    ReportItem.error(
+                        reports.messages.ObjectWithIdInUnexpectedContext(
+                            element.tag,
+                            self._element_id,
+                            self._context_element.tag,
+                            self._context_element.attrib.get("id", ""),
+                        )
+                    )
+                ]
+            return [
+                ReportItem.error(
+                    reports.messages.IdBelongsToUnexpectedType(
+                        self._element_id,
+                        expected_types=self._expected_types,
+                        current_type=element.tag,
+                    )
+                )
+            ]
+        if self._book_errors is None:
+            return [
+                ReportItem.error(
+                    reports.messages.IdNotFound(
+                        self._element_id,
+                        sorted(self._expected_types),
+                        self._context_element.tag,
+                        self._context_element.attrib.get("id", ""),
+                    )
+                )
+            ]
+        return self._book_errors
+
+    def _execute(self):
+        self._executed = True
+        for tag in self._tag_list:
+            element_list = self._context_element.xpath(
+                f'.//{tag}[@id="{self._element_id}"]'
+            )
+            if element_list:
+                self._element = element_list[0]
+                return
+
+
+# DEPRECATED, use IdProvider instead
 def does_id_exist(tree, check_id):
     """
     Checks to see if id exists in the xml dom passed
@@ -60,11 +193,12 @@ def does_id_exist(tree, check_id):
     # do not search in /cib/status, it may contain references to previously
     # existing and deleted resources and thus preventing creating them again
 
-    #pacemaker creates an implicit resource for the pacemaker_remote connection,
-    #which will be named the same as the value of the remote-node attribute of
-    #the explicit resource. So the value of nvpair named "remote-node" is
-    #considered to be id
-    existing = get_root(tree).xpath("""
+    # pacemaker creates an implicit resource for the pacemaker_remote
+    # connection, which will be named the same as the value of the remote-node
+    # attribute of the explicit resource. So the value of nvpair named
+    # "remote-node" is considered to be id
+    existing = get_root(tree).xpath(
+        """
         (
             /cib/*[name()!="status"]
             |
@@ -89,16 +223,25 @@ def does_id_exist(tree, check_id):
                 ]
             )
         ]
-    """.format(check_id))
+    """.format(
+            check_id
+        )
+    )
     return len(existing) > 0
 
+
+# DEPRECATED, use IdProvider instead
 def validate_id_does_not_exist(tree, _id):
     """
     tree cib etree node
     """
     if does_id_exist(tree, _id):
-        raise LibraryError(reports.id_already_exists(_id))
+        raise LibraryError(
+            ReportItem.error(reports.messages.IdAlreadyExists(_id))
+        )
 
+
+# DEPRECATED, use IdProvider instead
 def find_unique_id(tree, check_id, reserved_ids=None):
     """
     Returns check_id if it doesn't exist in the dom, otherwise it adds
@@ -116,6 +259,8 @@ def find_unique_id(tree, check_id, reserved_ids=None):
         counter += 1
     return temp_id
 
+
+# DEPRECATED, use ElementSearcher instead
 def find_element_by_tag_and_id(
     tag, context_element, element_id, none_if_id_unused=False, id_types=None
 ):
@@ -131,67 +276,38 @@ def find_element_by_tag_and_id(
         or raise a LibraryError if False
     list id_types optional list of descriptions for id / expected types of id
     """
-    tag_list = [tag] if isinstance(tag, str) else tag
-    if id_types is None:
-        id_type_list = tag_list
-    elif isinstance(id_types, str):
-        id_type_list = [id_types]
-    else:
-        id_type_list = id_types
-
-    element_list = context_element.xpath(
-        './/*[({0}) and @id="{1}"]'.format(
-            " or ".join(["self::{0}".format(one_tag) for one_tag in tag_list]),
-            element_id
-        )
+    searcher = ElementSearcher(
+        tag, element_id, context_element, element_type_desc=id_types
     )
+    if searcher.element_found():
+        return searcher.get_element()
+    report_list = searcher.get_errors()
+    if not none_if_id_unused:
+        raise LibraryError(*report_list)
+    filtered_reports = [
+        report_item
+        for report_item in report_list
+        if report_item.message.code != report_codes.ID_NOT_FOUND
+    ]
+    if filtered_reports:
+        raise LibraryError(*filtered_reports)
+    return None
 
-    if element_list:
-        return element_list[0]
 
-    element = get_root(context_element).find(
-        './/*[@id="{0}"]'.format(element_id)
-    )
-
-    if element is not None:
-        raise LibraryError(
-            reports.id_belongs_to_unexpected_type(
-                element_id,
-                expected_types=id_type_list,
-                current_type=element.tag
-            ) if element.tag not in tag_list
-            else reports.object_with_id_in_unexpected_context(
-                element.tag,
-                element_id,
-                context_element.tag,
-                context_element.attrib.get("id", "")
-            )
-        )
-
-    if none_if_id_unused:
-        return None
-
-    raise LibraryError(
-        reports.id_not_found(
-            element_id,
-            id_type_list,
-            context_element.tag,
-            context_element.attrib.get("id", "")
-        )
-    )
-
-def create_subelement_id(context_element, suffix, id_provider=None):
+def create_subelement_id(context_element, suffix, id_provider):
     proposed_id = sanitize_id(
         "{0}-{1}".format(context_element.get("id"), suffix)
     )
-    if id_provider:
-        return id_provider.allocate_id(proposed_id)
-    return find_unique_id(context_element, proposed_id)
+    return id_provider.allocate_id(proposed_id)
 
+
+# DEPRECATED
+# use ElementSearcher, IdProvider or pcs.lib.validate.ValueId instead
 def check_new_id_applicable(tree, description, _id):
     validate_id(_id, description)
     validate_id_does_not_exist(tree, _id)
 
+
 def get_configuration(tree):
     """
     Return 'configuration' element from tree, raise LibraryError if missing
@@ -199,6 +315,7 @@ def get_configuration(tree):
     """
     return sections.get(tree, sections.CONFIGURATION)
 
+
 def get_acls(tree):
     """
     Return 'acls' element from tree, create a new one if missing
@@ -206,6 +323,7 @@ def get_acls(tree):
     """
     return sections.get(tree, sections.ACLS)
 
+
 def get_alerts(tree):
     """
     Return 'alerts' element from tree, create a new one if missing
@@ -213,6 +331,7 @@ def get_alerts(tree):
     """
     return sections.get(tree, sections.ALERTS)
 
+
 def get_constraints(tree):
     """
     Return 'constraint' element from tree
@@ -220,6 +339,16 @@ def get_constraints(tree):
     """
     return sections.get(tree, sections.CONSTRAINTS)
 
+
+def get_crm_config(tree: Element) -> Element:
+    """
+    Return 'crm_config' element from tree, raise LibraryError if missing
+
+    tree -- cib etree node
+    """
+    return sections.get(tree, sections.CRM_CONFIG)
+
+
 def get_fencing_topology(tree):
     """
     Return the 'fencing-topology' element from the tree
@@ -227,6 +356,7 @@ def get_fencing_topology(tree):
     """
     return sections.get(tree, sections.FENCING_TOPOLOGY)
 
+
 def get_nodes(tree):
     """
     Return 'nodes' element from the tree
@@ -234,13 +364,16 @@ def get_nodes(tree):
     """
     return sections.get(tree, sections.NODES)
 
-def get_resources(tree):
+
+def get_resources(tree: Element) -> Element:
     """
     Return the 'resources' element from the tree
+
     tree -- cib etree node
     """
     return sections.get(tree, sections.RESOURCES)
 
+
 def get_status(tree):
     """
     Return the 'status' element from the tree
@@ -248,30 +381,45 @@ def get_status(tree):
     """
     return get_sub_element(tree, "status")
 
+
+def get_tags(tree: Element) -> Element:
+    """
+    Return 'tags' element from tree, create a new one if missing
+    tree -- cib etree node
+    """
+    return sections.get(tree, sections.TAGS)
+
+
 def _get_cib_version(cib, attribute, regexp, none_if_missing=False):
     version = cib.get(attribute)
     if version is None:
         if none_if_missing:
             return None
-        raise LibraryError(reports.cib_load_error_invalid_format(
-            "the attribute '{0}' of the element 'cib' is missing".format(
-                attribute
+        raise LibraryError(
+            ReportItem.error(
+                reports.messages.CibLoadErrorBadFormat(
+                    f"the attribute '{attribute}' of the element 'cib' "
+                    "is missing"
+                )
             )
-        ))
+        )
     match = regexp.match(version)
     if not match:
-        raise LibraryError(reports.cib_load_error_invalid_format(
-            (
-                "the attribute '{0}' of the element 'cib' has an invalid"
-                " value: '{1}'"
-            ).format(attribute, version)
-        ))
+        raise LibraryError(
+            ReportItem.error(
+                reports.messages.CibLoadErrorBadFormat(
+                    f"the attribute '{attribute}' of the element 'cib' has "
+                    f"an invalid value: '{version}'"
+                )
+            )
+        )
     return Version(
         int(match.group("major")),
         int(match.group("minor")),
-        int(match.group("rev")) if match.group("rev") else None
+        int(match.group("rev")) if match.group("rev") else None,
     )
 
+
 def get_pacemaker_version_by_which_cib_was_validated(cib):
     """
     Return version of pacemaker which validated specified cib as tree.
@@ -283,9 +431,10 @@ def get_pacemaker_version_by_which_cib_was_validated(cib):
     return _get_cib_version(
         cib,
         "validate-with",
-        re.compile(r"pacemaker-{0}".format(VERSION_FORMAT))
+        re.compile(r"pacemaker-{0}".format(VERSION_FORMAT)),
     )
 
+
 def get_cib_crm_feature_set(cib, none_if_missing=False):
     """
     Return crm_feature_set as pcs.common.tools.Version or raise LibraryError
@@ -298,5 +447,5 @@ def get_cib_crm_feature_set(cib, none_if_missing=False):
         cib,
         "crm_feature_set",
         re.compile(VERSION_FORMAT),
-        none_if_missing=none_if_missing
+        none_if_missing=none_if_missing,
     )
