@@ -1,8 +1,13 @@
 import json
 
-from pcs.common import report_codes
+from pcs.common import reports
+from pcs.common.reports import (
+    codes as report_codes,
+    ReportItemSeverity,
+)
+from pcs.common.reports.item import ReportItem
 from pcs.common.node_communicator import RequestData
-from pcs.lib import reports, node_communication_format
+from pcs.lib import node_communication_format
 from pcs.lib.communication.tools import (
     AllAtOnceStrategyMixin,
     AllSameDataMixin,
@@ -11,7 +16,6 @@ from pcs.lib.communication.tools import (
     SimpleResponseProcessingMixin,
     SimpleResponseProcessingNoResponseOnSuccessMixin,
 )
-from pcs.lib.errors import ReportItemSeverity
 from pcs.lib.node_communication import response_to_report_item
 
 
@@ -33,7 +37,9 @@ class GetOnlineTargets(
             return
         if not response.was_connected:
             report = (
-                reports.omitting_node(response.request.target.label)
+                ReportItem.warning(
+                    reports.messages.OmittingNode(response.request.target.label)
+                )
                 if self._ignore_offline_targets
                 else response_to_report_item(
                     response, forceable=report_codes.SKIP_OFFLINE_NODES
@@ -92,7 +98,9 @@ class CheckAuth(AllSameDataMixin, AllAtOnceStrategyMixin, RunRemotelyBase):
         )
         host_name = response.request.target.label
         if report is None:
-            report = reports.host_already_authorized(host_name)
+            report = ReportItem.info(
+                reports.messages.HostAlreadyAuthorized(host_name)
+            )
         else:
             # If we cannot connect it may be because a node's address and / or
             # port is not correct. Since these are part of authentication info
@@ -120,7 +128,11 @@ class GetHostInfo(AllSameDataMixin, AllAtOnceStrategyMixin, RunRemotelyBase):
         try:
             self._responses[host_name] = json.loads(response.data)
         except json.JSONDecodeError:
-            self._report(reports.invalid_response_format(host_name))
+            self._report(
+                ReportItem.error(
+                    reports.messages.InvalidResponseFormat(host_name)
+                )
+            )
 
     def before(self):
         self._responses = {}
@@ -138,8 +150,11 @@ class RunActionBase(
     _code_message_map = None
 
     def __init__(
-        self, report_processor, action_definition,
-        skip_offline_targets=False, allow_fails=False,
+        self,
+        report_processor,
+        action_definition,
+        skip_offline_targets=False,
+        allow_fails=False,
     ):
         super(RunActionBase, self).__init__(report_processor)
         self._set_skip_offline(skip_offline_targets)
@@ -186,20 +201,23 @@ class RunActionBase(
         try:
             results = json.loads(response.data)
         except ValueError:
-            self._report(reports.invalid_response_format(target.label))
+            self._report(
+                ReportItem.error(
+                    reports.messages.InvalidResponseFormat(target.label)
+                )
+            )
             return
         results = node_communication_format.response_to_result(
             results,
             self._response_key,
             list(self._action_definition.keys()),
-            target.label
+            target.label,
         )
         for key, item_response in sorted(results.items()):
             if self._is_success(item_response):
-                #only success process individually
+                # only success process individually
                 report = self._success_report(
-                    target.label,
-                    self._action_key_to_report(key),
+                    target.label, self._action_key_to_report(key),
                 )
             else:
                 report = self._failure_report(
@@ -208,18 +226,20 @@ class RunActionBase(
                     node_communication_format.get_format_result(
                         self._code_message_map
                     )(item_response),
-                    **self._action_error_force
+                    **self._action_error_force,
                 )
             self._report(report)
 
     def before(self):
-        self._report(self._start_report(
-            [
-                self._action_key_to_report(key)
-                for key in self._action_definition.keys()
-            ],
-            [target.label for target in self._target_list],
-        ))
+        self._report(
+            self._start_report(
+                [
+                    self._action_key_to_report(key)
+                    for key in self._action_definition.keys()
+                ],
+                [target.label for target in self._target_list],
+            )
+        )
 
     def _action_key_to_report(self, key):
         return self._key_to_report.get(key, key)
@@ -236,16 +256,23 @@ class ServiceAction(RunActionBase):
     def _failure_report(
         self, target_label, action, reason, severity, forceable
     ):
-        return reports.service_command_on_node_error(
-            target_label, action, reason, severity, forceable
+        return ReportItem(
+            severity=reports.item.ReportItemSeverity(severity, forceable),
+            message=reports.messages.ServiceCommandOnNodeError(
+                target_label, action, reason
+            ),
         )
 
     def _success_report(self, target_label, action):
-        return reports.service_command_on_node_success(target_label, action)
+        return ReportItem.info(
+            reports.messages.ServiceCommandOnNodeSuccess(target_label, action)
+        )
 
     def _start_report(self, action_list, target_label_list):
-        return reports.service_commands_on_nodes_started(
-            action_list, target_label_list
+        return ReportItem.info(
+            reports.messages.ServiceCommandsOnNodesStarted(
+                action_list, target_label_list
+            )
         )
 
     def _is_success(self, action_response):
@@ -253,7 +280,7 @@ class ServiceAction(RunActionBase):
 
 
 class FileActionBase(RunActionBase):
-    #pylint: disable=abstract-method, too-many-ancestors
+    # pylint: disable=abstract-method, too-many-ancestors
     def _init_properties(self):
         self._response_key = "files"
         self._force_code = report_codes.SKIP_FILE_DISTRIBUTION_ERRORS
@@ -269,16 +296,23 @@ class DistributeFiles(FileActionBase):
     def _failure_report(
         self, target_label, action, reason, severity, forceable
     ):
-        return reports.file_distribution_error(
-            target_label, action, reason, severity, forceable
+        return ReportItem(
+            severity=reports.item.ReportItemSeverity(severity, forceable),
+            message=reports.messages.FileDistributionError(
+                target_label, action, reason
+            ),
         )
 
     def _success_report(self, target_label, action):
-        return reports.file_distribution_success(target_label, action)
+        return ReportItem.info(
+            reports.messages.FileDistributionSuccess(target_label, action)
+        )
 
     def _start_report(self, action_list, target_label_list):
-        return reports.files_distribution_started(
-            action_list, target_label_list
+        return ReportItem.info(
+            reports.messages.FilesDistributionStarted(
+                action_list, target_label_list
+            )
         )
 
     def _is_success(self, action_response):
@@ -306,16 +340,23 @@ class RemoveFiles(FileActionBase):
     def _failure_report(
         self, target_label, action, reason, severity, forceable
     ):
-        return reports.file_remove_from_node_error(
-            target_label, action, reason, severity, forceable
+        return ReportItem(
+            severity=reports.item.ReportItemSeverity(severity, forceable),
+            message=reports.messages.FileRemoveFromNodeError(
+                target_label, action, reason
+            ),
         )
 
     def _success_report(self, target_label, action):
-        return reports.file_remove_from_node_success(target_label, action)
+        return ReportItem.info(
+            reports.messages.FileRemoveFromNodeSuccess(target_label, action)
+        )
 
     def _start_report(self, action_list, target_label_list):
-        return reports.files_remove_from_nodes_started(
-            action_list, target_label_list
+        return ReportItem.info(
+            reports.messages.FilesRemoveFromNodesStarted(
+                action_list, target_label_list
+            )
         )
 
     def _is_success(self, action_response):
@@ -334,28 +375,46 @@ class RemoveFilesWithoutForces(RemoveFiles):
 
 
 class StartCluster(
-    SimpleResponseProcessingNoResponseOnSuccessMixin, AllSameDataMixin,
-    AllAtOnceStrategyMixin, RunRemotelyBase,
+    SimpleResponseProcessingNoResponseOnSuccessMixin,
+    AllSameDataMixin,
+    AllAtOnceStrategyMixin,
+    RunRemotelyBase,
 ):
     def _get_request_data(self):
         return RequestData("remote/cluster_start")
 
     def before(self):
-        self._report(reports.cluster_start_started(self._target_label_list))
+        self._report(
+            ReportItem.info(
+                reports.messages.ClusterStartStarted(
+                    sorted(self._target_label_list)
+                )
+            )
+        )
 
 
 class EnableCluster(
-    SimpleResponseProcessingMixin, AllSameDataMixin, AllAtOnceStrategyMixin,
+    SimpleResponseProcessingMixin,
+    AllSameDataMixin,
+    AllAtOnceStrategyMixin,
     RunRemotelyBase,
 ):
     def _get_request_data(self):
         return RequestData("remote/cluster_enable")
 
     def _get_success_report(self, node_label):
-        return reports.cluster_enable_success(node_label)
+        return ReportItem.info(
+            reports.messages.ClusterEnableSuccess(node_label)
+        )
 
     def before(self):
-        self._report(reports.cluster_enable_started(self._target_label_list))
+        self._report(
+            ReportItem.info(
+                reports.messages.ClusterEnableStarted(
+                    sorted(self._target_label_list)
+                )
+            )
+        )
 
 
 class CheckPacemakerStarted(
@@ -375,16 +434,19 @@ class CheckPacemakerStarted(
                 # If the node is offline, we only get the "offline" key. Asking
                 # for any other in that case results in KeyError which is not
                 # what we want.
-                if (
-                    parsed_response.get("pending", True)
-                    or
-                    not parsed_response.get("online", False)
-                ):
+                if parsed_response.get(
+                    "pending", True
+                ) or not parsed_response.get("online", False):
                     self._not_yet_started_target_list.append(target)
                     return
-                report = reports.cluster_start_success(target.label)
+                report = ReportItem.info(
+                    reports.messages.ClusterStartSuccess(target.label)
+                )
             except (json.JSONDecodeError, KeyError):
-                report = reports.invalid_response_format(target.label)
+                report = ReportItem.error(
+                    reports.messages.InvalidResponseFormat(target.label)
+                )
+
         else:
             if not response.was_connected:
                 self._not_yet_started_target_list.append(target)
@@ -401,8 +463,10 @@ class CheckPacemakerStarted(
 
 
 class UpdateKnownHosts(
-    SimpleResponseProcessingNoResponseOnSuccessMixin, AllSameDataMixin,
-    AllAtOnceStrategyMixin, RunRemotelyBase,
+    SimpleResponseProcessingNoResponseOnSuccessMixin,
+    AllSameDataMixin,
+    AllAtOnceStrategyMixin,
+    RunRemotelyBase,
 ):
     def __init__(
         self, report_processor, known_hosts_to_add, known_hosts_to_remove
@@ -448,19 +512,27 @@ class RemoveNodesFromCib(
             output = json.loads(response.data)
             if output["code"] != "success":
                 self._report(
-                    reports.node_remove_in_pacemaker_failed(
-                        self._nodes_to_remove,
-                        node=node_label,
-                        reason=output["message"],
+                    ReportItem.error(
+                        reports.messages.NodeRemoveInPacemakerFailed(
+                            node_list_to_remove=self._nodes_to_remove,
+                            node=node_label,
+                            reason=output["message"],
+                        )
                     )
                 )
         except (KeyError, json.JSONDecodeError):
-            self._report(reports.invalid_response_format(node_label))
+            self._report(
+                ReportItem.error(
+                    reports.messages.InvalidResponseFormat(node_label)
+                )
+            )
 
 
 class SendPcsdSslCertAndKey(
-    SimpleResponseProcessingMixin, AllSameDataMixin, AllAtOnceStrategyMixin,
-    RunRemotelyBase
+    SimpleResponseProcessingMixin,
+    AllSameDataMixin,
+    AllAtOnceStrategyMixin,
+    RunRemotelyBase,
 ):
     def __init__(self, report_processor, ssl_cert, ssl_key):
         super().__init__(report_processor)
@@ -470,20 +542,16 @@ class SendPcsdSslCertAndKey(
     def _get_request_data(self):
         return RequestData(
             "remote/set_certs",
-            [("ssl_cert", self._ssl_cert), ("ssl_key", self._ssl_key)]
+            [("ssl_cert", self._ssl_cert), ("ssl_key", self._ssl_key)],
         )
 
     def _get_success_report(self, node_label):
-        return reports.pcsd_ssl_cert_and_key_set_success(node_label)
+        return ReportItem.info(
+            reports.messages.PcsdSslCertAndKeySetSuccess(node_label)
+        )
 
 
 def _force(force_code, is_forced):
     if is_forced:
-        return dict(
-            severity=ReportItemSeverity.WARNING,
-            forceable=None,
-        )
-    return dict(
-        severity=ReportItemSeverity.ERROR,
-        forceable=force_code,
-    )
+        return dict(severity=ReportItemSeverity.WARNING, forceable=None,)
+    return dict(severity=ReportItemSeverity.ERROR, forceable=force_code,)
