@@ -1,6 +1,7 @@
 import re
 
-from pcs.lib import reports
+from pcs.common import reports
+from pcs.common.reports.item import ReportItem
 from pcs.lib.errors import LibraryError
 
 
@@ -21,6 +22,7 @@ def is_boolean(val) -> bool:
     """
     return val.lower() in _BOOLEAN
 
+
 def is_true(val) -> bool:
     """
     Does pacemaker consider a value to be true?
@@ -29,6 +31,7 @@ def is_true(val) -> bool:
     """
     return val.lower() in _BOOLEAN_TRUE
 
+
 def is_false(val) -> bool:
     """
     Does pacemaker consider a value to be false?
@@ -37,12 +40,14 @@ def is_false(val) -> bool:
     """
     return val.lower() in _BOOLEAN_FALSE
 
+
 def is_score(value):
     if not value:
         return False
     unsigned_value = value[1:] if value[0] in ("+", "-") else value
     return unsigned_value == SCORE_INFINITY or unsigned_value.isdigit()
 
+
 def timeout_to_seconds(timeout, return_unknown=False):
     """
     Transform pacemaker style timeout to number of seconds
@@ -67,10 +72,11 @@ def timeout_to_seconds(timeout, return_unknown=False):
         "hr": 3600,
     }
     for suffix, multiplier in suffix_multiplier.items():
-        if timeout.endswith(suffix) and timeout[:-len(suffix)].isdigit():
-            return int(timeout[:-len(suffix)]) * multiplier
+        if timeout.endswith(suffix) and timeout[: -len(suffix)].isdigit():
+            return int(timeout[: -len(suffix)]) * multiplier
     return timeout if return_unknown else None
 
+
 def get_valid_timeout_seconds(timeout_candidate):
     """
     Transform pacemaker style timeout to number of seconds, raise LibraryError
@@ -81,9 +87,14 @@ def get_valid_timeout_seconds(timeout_candidate):
         return None
     wait_timeout = timeout_to_seconds(timeout_candidate)
     if wait_timeout is None:
-        raise LibraryError(reports.invalid_timeout(timeout_candidate))
+        raise LibraryError(
+            ReportItem.error(
+                reports.messages.InvalidTimeoutValue(timeout_candidate)
+            )
+        )
     return wait_timeout
 
+
 def validate_id(id_candidate, description="id", reporter=None):
     """
     Validate a pacemaker id, raise LibraryError on invalid id.
@@ -95,34 +106,45 @@ def validate_id(id_candidate, description="id", reporter=None):
     # http://www.w3.org/TR/REC-xml-names/#NT-NCName
     # http://www.w3.org/TR/REC-xml/#NT-Name
     if not id_candidate:
-        report = reports.invalid_id_is_empty(id_candidate, description)
+        report_item = ReportItem.error(
+            reports.messages.InvalidIdIsEmpty(description)
+        )
         if reporter is None:
             # we check for None so it works with an empty list as well
-            raise LibraryError(report)
-        reporter.append(report)
+            raise LibraryError(report_item)
+        reporter.append(report_item)
         return
     if _ID_FIRST_CHAR_NOT_RE.match(id_candidate[0]):
-        report = reports.invalid_id_bad_char(
-            id_candidate, description, id_candidate[0], True
+        report_item = ReportItem.error(
+            reports.messages.InvalidIdBadChar(
+                id_candidate, description, id_candidate[0], True,
+            )
         )
         if reporter is not None:
-            reporter.append(report)
+            reporter.append(report_item)
         else:
-            raise LibraryError(report)
+            raise LibraryError(report_item)
     for char in id_candidate[1:]:
         if _ID_REST_CHARS_NOT_RE.match(char):
-            report = reports.invalid_id_bad_char(
-                id_candidate, description, char, False
+            report_item = ReportItem.error(
+                reports.messages.InvalidIdBadChar(
+                    id_candidate, description, char, False,
+                )
             )
             if reporter is not None:
-                reporter.append(report)
+                reporter.append(report_item)
             else:
-                raise LibraryError(report)
+                raise LibraryError(report_item)
+
 
 def sanitize_id(id_candidate, replacement=""):
     if not id_candidate:
         return id_candidate
-    return "".join([
-        "" if _ID_FIRST_CHAR_NOT_RE.match(id_candidate[0]) else id_candidate[0],
-        _ID_REST_CHARS_NOT_RE.sub(replacement, id_candidate[1:])
-    ])
+    return "".join(
+        [
+            ""
+            if _ID_FIRST_CHAR_NOT_RE.match(id_candidate[0])
+            else id_candidate[0],
+            _ID_REST_CHARS_NOT_RE.sub(replacement, id_candidate[1:]),
+        ]
+    )
