@@ -2,10 +2,10 @@ import re
 from os import path
 
 from pcs import settings
-from pcs.lib import (
-    external,
-    reports,
-)
+from pcs.common import reports
+from pcs.common.reports import ReportProcessor
+from pcs.common.reports.item import ReportItem
+from pcs.lib import external
 from pcs.lib.tools import dict_to_environment_file, environment_file_to_dict
 from pcs.lib.errors import LibraryError
 
@@ -32,8 +32,8 @@ def _even_number_of_nodes_and_no_qdevice(
     """
     return (
         not corosync_conf_facade.has_quorum_device()
-        and
-        (len(corosync_conf_facade.get_nodes()) + node_number_modifier) % 2 == 0
+        and (len(corosync_conf_facade.get_nodes()) + node_number_modifier) % 2
+        == 0
     )
 
 
@@ -54,12 +54,9 @@ def is_auto_tie_breaker_needed(
         _even_number_of_nodes_and_no_qdevice(
             corosync_conf_facade, node_number_modifier
         )
-        and
-        is_sbd_installed(runner)
-        and
-        is_sbd_enabled(runner)
-        and
-        not is_device_set_local()
+        and is_sbd_installed(runner)
+        and is_sbd_enabled(runner)
+        and not is_device_set_local()
     )
 
 
@@ -68,12 +65,14 @@ def atb_has_to_be_enabled_pre_enable_check(corosync_conf_facade):
     Returns True whenever quorum option auto_tie_breaker is needed to be enabled
     for proper working of SBD fencing. False if it is not needed. This function
     doesn't check if sbd is installed nor enabled.
-     """
+    """
+    # fmt: off
     return (
         not corosync_conf_facade.is_enabled_auto_tie_breaker()
         and
         _even_number_of_nodes_and_no_qdevice(corosync_conf_facade)
     )
+    # fmt: on
 
 
 def atb_has_to_be_enabled(runner, corosync_conf_facade, node_number_modifier=0):
@@ -88,6 +87,7 @@ def atb_has_to_be_enabled(runner, corosync_conf_facade, node_number_modifier=0):
         This can be useful to test whenever is ATB needed when adding/removeing
         node.
     """
+    # fmt: off
     return (
         not corosync_conf_facade.is_enabled_auto_tie_breaker()
         and
@@ -95,6 +95,7 @@ def atb_has_to_be_enabled(runner, corosync_conf_facade, node_number_modifier=0):
             runner, corosync_conf_facade, node_number_modifier
         )
     )
+    # fmt: on
 
 
 def validate_new_nodes_devices(nodes_devices):
@@ -105,12 +106,14 @@ def validate_new_nodes_devices(nodes_devices):
     """
     if is_device_set_local():
         return validate_nodes_devices(
-            nodes_devices,
-            adding_nodes_to_sbd_enabled_cluster=True
+            nodes_devices, adding_nodes_to_sbd_enabled_cluster=True
         )
     return [
-        reports.sbd_with_devices_not_used_cannot_set_device(node)
-        for node, devices in nodes_devices.items() if devices
+        ReportItem.error(
+            reports.messages.SbdWithDevicesNotUsedCannotSetDevice(node)
+        )
+        for node, devices in nodes_devices.items()
+        if devices
     ]
 
 
@@ -130,19 +133,31 @@ def validate_nodes_devices(
     for node_label, device_list in node_device_dict.items():
         if not device_list:
             report_item_list.append(
-                reports.sbd_no_device_for_node(
-                    node_label,
-                    sbd_enabled_in_cluster=adding_nodes_to_sbd_enabled_cluster
+                ReportItem.error(
+                    reports.messages.SbdNoDeviceForNode(
+                        node_label,
+                        sbd_enabled_in_cluster=(
+                            adding_nodes_to_sbd_enabled_cluster
+                        ),
+                    )
                 )
             )
         elif len(device_list) > settings.sbd_max_device_num:
-            report_item_list.append(reports.sbd_too_many_devices_for_node(
-                node_label, device_list, settings.sbd_max_device_num
-            ))
+            report_item_list.append(
+                ReportItem.error(
+                    reports.messages.SbdTooManyDevicesForNode(
+                        node_label, device_list, settings.sbd_max_device_num
+                    )
+                )
+            )
         for device in device_list:
             if not device or not path.isabs(device):
                 report_item_list.append(
-                    reports.sbd_device_path_not_absolute(device, node_label)
+                    ReportItem.error(
+                        reports.messages.SbdDevicePathNotAbsolute(
+                            device, node_label
+                        )
+                    )
                 )
     return report_item_list
 
@@ -167,7 +182,7 @@ def get_default_sbd_config():
         "SBD_PACEMAKER": "yes",
         "SBD_STARTMODE": "always",
         "SBD_WATCHDOG_DEV": settings.sbd_watchdog_default,
-        "SBD_WATCHDOG_TIMEOUT": "5"
+        "SBD_WATCHDOG_TIMEOUT": "5",
     }
 
 
@@ -181,9 +196,11 @@ def get_local_sbd_config():
         with open(settings.sbd_config, "r") as sbd_cfg:
             return sbd_cfg.read()
     except EnvironmentError as e:
-        raise LibraryError(reports.unable_to_get_sbd_config(
-            "local node", str(e)
-        ))
+        raise LibraryError(
+            ReportItem.error(
+                reports.messages.UnableToGetSbdConfig("local node", str(e))
+            )
+        )
 
 
 def get_sbd_service_name() -> str:
@@ -211,7 +228,7 @@ def is_sbd_installed(runner):
 
 
 def initialize_block_devices(
-    report_processor, cmd_runner, device_list, option_dict
+    report_processor: ReportProcessor, cmd_runner, device_list, option_dict
 ):
     """
     Initialize devices with specified options in option_dict.
@@ -222,8 +239,10 @@ def initialize_block_devices(
     device_list -- list of strings
     option_dict -- dictionary of options and their values
     """
-    report_processor.process(
-        reports.sbd_device_initialization_started(device_list)
+    report_processor.report(
+        ReportItem.info(
+            reports.messages.SbdDeviceInitializationStarted(device_list)
+        )
     )
 
     cmd = [settings.sbd_binary]
@@ -237,10 +256,16 @@ def initialize_block_devices(
     _, std_err, ret_val = cmd_runner.run(cmd)
     if ret_val != 0:
         raise LibraryError(
-            reports.sbd_device_initialization_error(device_list, std_err)
+            ReportItem.error(
+                reports.messages.SbdDeviceInitializationError(
+                    device_list, std_err
+                )
+            )
+        )
+    report_processor.report(
+        ReportItem.info(
+            reports.messages.SbdDeviceInitializationSuccess(device_list)
         )
-    report_processor.process(
-        reports.sbd_device_initialization_success(device_list)
     )
 
 
@@ -257,10 +282,7 @@ def get_local_sbd_device_list():
     devices = cfg["SBD_DEVICE"]
     if devices.startswith('"') and devices.endswith('"'):
         devices = devices[1:-1]
-    return [
-        device.strip()
-        for device in devices.split(";") if device.strip()
-    ]
+    return [device.strip() for device in devices.split(";") if device.strip()]
 
 
 def is_device_set_local():
@@ -283,7 +305,11 @@ def get_device_messages_info(cmd_runner, device):
     )
     if ret_val != 0:
         # sbd writes error message into std_out
-        raise LibraryError(reports.sbd_device_list_error(device, std_out))
+        raise LibraryError(
+            ReportItem.error(
+                reports.messages.SbdDeviceListError(device, std_out)
+            )
+        )
     return std_out
 
 
@@ -299,7 +325,11 @@ def get_device_sbd_header_dump(cmd_runner, device):
     )
     if ret_val != 0:
         # sbd writes error message into std_out
-        raise LibraryError(reports.sbd_device_dump_error(device, std_out))
+        raise LibraryError(
+            ReportItem.error(
+                reports.messages.SbdDeviceDumpError(device, std_out)
+            )
+        )
     return std_out
 
 
@@ -316,9 +346,13 @@ def set_message(cmd_runner, device, node_name, message):
         [settings.sbd_binary, "-d", device, "message", node_name, message]
     )
     if ret_val != 0:
-        raise LibraryError(reports.sbd_device_message_error(
-            device, node_name, message, std_err
-        ))
+        raise LibraryError(
+            ReportItem.error(
+                reports.messages.SbdDeviceMessageError(
+                    device, node_name, message, std_err
+                )
+            )
+        )
 
 
 def get_available_watchdogs(cmd_runner):
@@ -332,11 +366,14 @@ def get_available_watchdogs(cmd_runner):
         [settings.sbd_binary, "query-watchdog"]
     )
     if ret_val != 0:
-        raise LibraryError(reports.sbd_list_watchdog_error(std_err))
+        raise LibraryError(
+            ReportItem.error(reports.messages.SbdListWatchdogError(std_err))
+        )
     return {
         match.group("watchdog"): {
             key: match.group(key) for key in ["identity", "driver", "caution"]
-        } for match in re.finditer(regex, std_out, re.MULTILINE)
+        }
+        for match in re.finditer(regex, std_out, re.MULTILINE)
     }
 
 
@@ -347,6 +384,14 @@ def test_watchdog(cmd_runner, watchdog=None):
     std_out, dummy_std_err, ret_val = cmd_runner.run(cmd)
     if ret_val:
         if "Multiple watchdog devices discovered" in std_out:
-            raise LibraryError(reports.sbd_watchdog_test_multiple_devices())
-        raise LibraryError(reports.sbd_watchdog_test_error(std_out))
-    raise LibraryError(reports.sbd_watchdog_test_failed())
+            raise LibraryError(
+                ReportItem.error(
+                    reports.messages.SbdWatchdogTestMultipleDevices()
+                )
+            )
+        raise LibraryError(
+            ReportItem.error(reports.messages.SbdWatchdogTestError(std_out))
+        )
+    raise LibraryError(
+        ReportItem.error(reports.messages.SbdWatchdogTestFailed())
+    )
