@@ -11,6 +11,8 @@ from pcs_test.tools.fixture_cib import modify_cib
 from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.xml import etree_to_str
 
+from pcs import settings
+
 # pylint: disable=too-many-arguments
 
 DEFAULT_WAIT_TIMEOUT = 10
@@ -22,12 +24,15 @@ AGENT_FILENAME_MAP = {
     "ocf:pacemaker:booth-site": "resource_agent_ocf_pacemaker_booth-site.xml",
 }
 
+
 def _fixture_state_resources_xml(
-    resource_id="A", resource_agent="ocf::heartbeat:Dummy", role="Started",
-    failed="false", node_name="node1"
+    resource_id="A",
+    resource_agent="ocf::heartbeat:Dummy",
+    role="Started",
+    failed="false",
+    node_name="node1",
 ):
-    return(
-        """
+    return """
         <resources>
             <resource
                 id="{resource_id}"
@@ -39,18 +44,28 @@ def _fixture_state_resources_xml(
             </resource>
         </resources>
         """.format(
-            resource_id=resource_id,
-            resource_agent=resource_agent,
-            role=role,
-            failed=failed,
-            node_name=node_name,
-        )
+        resource_id=resource_id,
+        resource_agent=resource_agent,
+        role=role,
+        failed=failed,
+        node_name=node_name,
     )
 
+
 def _fixture_state_node_xml(
-    id, name, type="member", online=True, standby=False, standby_onfail=False,
-    maintenance=False, pending=False, unclean=False, shutdown=False,
-    expected_up=True, is_dc=False, resources_running=0
+    id,
+    name,
+    type="member",
+    online=True,
+    standby=False,
+    standby_onfail=False,
+    maintenance=False,
+    pending=False,
+    unclean=False,
+    shutdown=False,
+    expected_up=True,
+    is_dc=False,
+    resources_running=0,
 ):
     # This function uses a "clever" way of defaulting an input **dict containing
     # attributes of an xml element.
@@ -69,15 +84,60 @@ def _fixture_state_node_xml(
     return "<node {0}/>".format(" ".join(xml_attrs))
 
 
-class PcmkShortcuts():
+class PcmkShortcuts:
+    # pylint: disable=too-many-public-methods
     def __init__(self, calls):
         self.__calls = calls
         self.default_wait_timeout = DEFAULT_WAIT_TIMEOUT
         self.default_wait_error_returncode = WAIT_TIMEOUT_EXPIRED_RETURNCODE
 
+    def can_fence_history_manage(
+        self,
+        name="runner.pcmk.can_fence_history_manage",
+        stderr="--history --cleanup --broadcast",
+        instead=None,
+    ):
+        """
+        Create a call to check if fence_history is supported by stonith_admin
+
+        string name -- key of the call
+        string stderr -- stonith_admin help text
+        string instead -- key of call instead of which this new call is to be
+            placed
+        """
+        self.__calls.place(
+            name,
+            RunnerCall("stonith_admin --help-all", stderr=stderr),
+            instead=instead,
+        )
+
+    def can_fence_history_status(
+        self,
+        name="runner.pcmk.can_fence_history_status",
+        stderr="--fence-history",
+        instead=None,
+    ):
+        """
+        Create a call to check if fence_history is supported by crm_mon
+
+        string name -- key of the call
+        string stderr -- crm_mon help text
+        string instead -- key of call instead of which this new call is to be
+            placed
+        """
+        self.__calls.place(
+            name,
+            RunnerCall("crm_mon --help-all", stderr=stderr),
+            instead=instead,
+        )
+
     def fence_history_get(
-        self, name="runner.pcmk.fence_history_get", node=None, stdout="",
-        stderr="", returncode=0
+        self,
+        name="runner.pcmk.fence_history_get",
+        node=None,
+        stdout="",
+        stderr="",
+        returncode=0,
     ):
         """
         Create call for getting plain text fencing history.
@@ -91,7 +151,7 @@ class PcmkShortcuts():
         self.__calls.place(
             name,
             RunnerCall(
-                "/usr/sbin/stonith_admin --history {0} --verbose".format(node),
+                "stonith_admin --history {0} --verbose".format(node),
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
@@ -99,8 +159,12 @@ class PcmkShortcuts():
         )
 
     def fence_history_cleanup(
-        self, name="runner.pcmk.fence_history_cleanup", node=None, stdout="",
-        stderr="", returncode=0
+        self,
+        name="runner.pcmk.fence_history_cleanup",
+        node=None,
+        stdout="",
+        stderr="",
+        returncode=0,
     ):
         """
         Create call for cleaning fencing history up.
@@ -114,7 +178,7 @@ class PcmkShortcuts():
         self.__calls.place(
             name,
             RunnerCall(
-                "/usr/sbin/stonith_admin --history {0} --cleanup".format(node),
+                "stonith_admin --history {0} --cleanup".format(node),
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
@@ -122,8 +186,11 @@ class PcmkShortcuts():
         )
 
     def fence_history_update(
-        self, name="runner.pcmk.fence_history_update", stdout="", stderr="",
-        returncode=0
+        self,
+        name="runner.pcmk.fence_history_update",
+        stdout="",
+        stderr="",
+        returncode=0,
     ):
         """
         Create call for updating fencing history.
@@ -136,7 +203,7 @@ class PcmkShortcuts():
         self.__calls.place(
             name,
             RunnerCall(
-                "/usr/sbin/stonith_admin --history * --broadcast",
+                "stonith_admin --history * --broadcast",
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
@@ -144,9 +211,15 @@ class PcmkShortcuts():
         )
 
     def load_state(
-        self, name="runner.pcmk.load_state", filename="crm_mon.minimal.xml",
-        resources=None, raw_resources=None, nodes=None, stdout="", stderr="",
-        returncode=0
+        self,
+        name="runner.pcmk.load_state",
+        filename="crm_mon.minimal.xml",
+        resources=None,
+        raw_resources=None,
+        nodes=None,
+        stdout="",
+        stderr="",
+        returncode=0,
     ):
         """
         Create call for loading pacemaker state.
@@ -160,10 +233,8 @@ class PcmkShortcuts():
         int returncode -- crm_mon's returncode
         """
         # pylint: disable=too-many-boolean-expressions
-        if (
-            (resources or raw_resources is not None or nodes)
-            and
-            (stdout or stderr or returncode)
+        if (resources or raw_resources is not None or nodes) and (
+            stdout or stderr or returncode
         ):
             raise AssertionError(
                 "Cannot specify resources or nodes when stdout, stderr or "
@@ -174,15 +245,15 @@ class PcmkShortcuts():
                 "Cannot use 'resources' and 'raw_resources' together"
             )
 
-        if (stdout or stderr or returncode):
+        if stdout or stderr or returncode:
             self.__calls.place(
                 name,
                 RunnerCall(
                     "crm_mon --one-shot --as-xml --inactive",
                     stdout=stdout,
                     stderr=stderr,
-                    returncode=returncode
-                )
+                    returncode=returncode,
+                ),
             )
             return
 
@@ -202,12 +273,18 @@ class PcmkShortcuts():
                 )
 
         # set correct number of nodes and resources into the status
-        resources_count = len(state.xpath(" | ".join([
-            "./resources/bundle",
-            "./resources/clone",
-            "./resources/group",
-            "./resources/resource",
-        ])))
+        resources_count = len(
+            state.xpath(
+                " | ".join(
+                    [
+                        "./resources/bundle",
+                        "./resources/clone",
+                        "./resources/group",
+                        "./resources/resource",
+                    ]
+                )
+            )
+        )
         nodes_count = len(state.findall("./nodes/node"))
         state.find("./summary/nodes_configured").set("number", str(nodes_count))
         state.find("./summary/resources_configured").set(
@@ -219,13 +296,18 @@ class PcmkShortcuts():
             RunnerCall(
                 "crm_mon --one-shot --as-xml --inactive",
                 stdout=etree_to_str(state),
-            )
+            ),
         )
 
     def load_state_plaintext(
-        self, name="runner.pcmk.load_state_plaintext",
-        inactive=True, verbose=False, fence_history=False,
-        stdout="", stderr="", returncode=0,
+        self,
+        name="runner.pcmk.load_state_plaintext",
+        inactive=True,
+        verbose=False,
+        fence_history=False,
+        stdout="",
+        stderr="",
+        returncode=0,
     ):
         """
         Create a call for loading plaintext pacemaker status
@@ -242,9 +324,9 @@ class PcmkShortcuts():
         if inactive:
             flags.append("--inactive")
         if verbose:
-            flags.extend([
-                "--show-detail", "--show-node-attributes", "--failcounts"
-            ])
+            flags.extend(
+                ["--show-detail", "--show-node-attributes", "--failcounts"]
+            )
             if fence_history:
                 flags.append("--fence-history=3")
         self.__calls.place(
@@ -258,8 +340,11 @@ class PcmkShortcuts():
         )
 
     def load_ticket_state_plaintext(
-        self, name="runner.pcmk.load_ticket_state_plaintext",
-        stdout="", stderr="", returncode=0,
+        self,
+        name="runner.pcmk.load_ticket_state_plaintext",
+        stdout="",
+        stderr="",
+        returncode=0,
     ):
         """
         Create a call for loading plaintext tickets status
@@ -285,6 +370,7 @@ class PcmkShortcuts():
         agent_name="ocf:heartbeat:Dummy",
         agent_filename=None,
         agent_is_missing=False,
+        stderr=None,
         instead=None,
     ):
         """
@@ -303,30 +389,34 @@ class PcmkShortcuts():
         elif agent_name in AGENT_FILENAME_MAP:
             agent_metadata_filename = AGENT_FILENAME_MAP[agent_name]
         elif not agent_is_missing:
-            raise AssertionError((
-                "Filename with metadata of agent '{0}' not specified.\n"
-                "Please specify file with metadata for agent:\n"
-                "  a) explicitly for this test:"
-                " config.runner.pcmk.load_agent(agent_name='{0}',"
-                " filename='FILENAME_HERE.xml')\n"
-                "  b) implicitly for agent '{0}' in 'AGENT_FILENAME_MAP' in"
-                " '{1}'\n"
-                "Place agent metadata into '{2}FILENAME_HERE.xml'"
-            ).format(agent_name, os.path.realpath(__file__), rc("")))
+            raise AssertionError(
+                (
+                    "Filename with metadata of agent '{0}' not specified.\n"
+                    "Please specify file with metadata for agent:\n"
+                    "  a) explicitly for this test:"
+                    " config.runner.pcmk.load_agent(agent_name='{0}',"
+                    " filename='FILENAME_HERE.xml')\n"
+                    "  b) implicitly for agent '{0}' in 'AGENT_FILENAME_MAP' in"
+                    " '{1}'\n"
+                    "Place agent metadata into '{2}FILENAME_HERE.xml'"
+                ).format(agent_name, os.path.realpath(__file__), rc(""))
+            )
 
         if agent_is_missing:
+            if stderr is None:
+                stderr = (
+                    f"Agent {agent_name} not found or does not support "
+                    "meta-data: Invalid argument (22)\n"
+                    f"Metadata query for {agent_name} failed: Input/output "
+                    "error\n"
+                )
             self.__calls.place(
                 name,
                 RunnerCall(
                     "crm_resource --show-metadata {0}".format(agent_name),
                     stdout="",
-                    stderr=(
-                        f"Agent {agent_name} not found or does not support "
-                            "meta-data: Invalid argument (22)\n"
-                        f"Metadata query for {agent_name} failed: Input/output "
-                            "error\n"
-                    ),
-                    returncode=74
+                    stderr=stderr,
+                    returncode=74,
                 ),
                 instead=instead,
             )
@@ -337,7 +427,8 @@ class PcmkShortcuts():
                 name,
                 RunnerCall(
                     "crm_resource --show-metadata {0}".format(agent_name),
-                    stdout=a_file.read()
+                    stdout=a_file.read(),
+                    stderr=stderr,
                 ),
                 instead=instead,
             )
@@ -369,18 +460,24 @@ class PcmkShortcuts():
         self.__calls.place(
             name,
             RunnerCall(
-                "/usr/libexec/pacemaker/pacemaker-fenced metadata",
+                f"{settings.pacemaker_fenced} metadata",
                 stdout=stdout,
                 stderr=stderr,
-                returncode=returncode
+                returncode=returncode,
             ),
             before=before,
             instead=instead,
         )
 
     def local_node_name(
-        self, name="runner.pcmk.local_node_name", instead=None, before=None,
-        node_name="", stdout="", stderr="", returncode=0
+        self,
+        name="runner.pcmk.local_node_name",
+        instead=None,
+        before=None,
+        node_name="",
+        stdout="",
+        stderr="",
+        returncode=0,
     ):
         """
         Create a call for crm_node --name
@@ -407,7 +504,7 @@ class PcmkShortcuts():
                 " ".join(cmd),
                 stdout=(node_name if node_name else stdout),
                 stderr=stderr,
-                returncode=returncode
+                returncode=returncode,
             ),
             before=before,
             instead=instead,
@@ -420,9 +517,10 @@ class PcmkShortcuts():
         before=None,
         resource=None,
         node=None,
+        strict=False,
         stdout="",
         stderr="",
-        returncode=0
+        returncode=0,
     ):
         """
         Create a call for crm_resource --cleanup
@@ -434,6 +532,7 @@ class PcmkShortcuts():
             placed
         string resource -- the id of a resource to be cleaned
         string node -- the name of the node where resources should be cleaned
+        bool strict -- strict mode of 'crm_resource cleanup' enabled?
         string stdout -- crm_resource's stdout
         string stderr -- crm_resource's stderr
         int returncode -- crm_resource's returncode
@@ -443,13 +542,15 @@ class PcmkShortcuts():
             cmd.extend(["--resource", resource])
         if node:
             cmd.extend(["--node", node])
+        if strict:
+            cmd.extend(["--force"])
         self.__calls.place(
             name,
             RunnerCall(
                 " ".join(cmd),
                 stdout=stdout,
                 stderr=stderr,
-                returncode=returncode
+                returncode=returncode,
             ),
             before=before,
             instead=instead,
@@ -466,7 +567,7 @@ class PcmkShortcuts():
         lifetime=None,
         stdout="",
         stderr="",
-        returncode=0
+        returncode=0,
     ):
         """
         Create a call for crm_resource --move
@@ -502,7 +603,7 @@ class PcmkShortcuts():
         lifetime=None,
         stdout="",
         stderr="",
-        returncode=0
+        returncode=0,
     ):
         """
         Create a call for crm_resource --ban
@@ -538,7 +639,7 @@ class PcmkShortcuts():
         expired=None,
         stdout="",
         stderr="",
-        returncode=0
+        returncode=0,
     ):
         """
         Create a call for crm_resource --clear
@@ -576,7 +677,7 @@ class PcmkShortcuts():
         expired=None,
         stdout="",
         stderr="",
-        returncode=0
+        returncode=0,
     ):
         cmd = ["crm_resource", action]
         if resource:
@@ -595,7 +696,7 @@ class PcmkShortcuts():
                 " ".join(cmd),
                 stdout=stdout,
                 stderr=stderr,
-                returncode=returncode
+                returncode=returncode,
             ),
             before=before,
             instead=instead,
@@ -611,8 +712,7 @@ class PcmkShortcuts():
         string stderr -- crm_resource help text
         """
         self.__calls.place(
-            name,
-            RunnerCall("crm_resource -?", stderr=stderr),
+            name, RunnerCall("crm_resource -?", stderr=stderr),
         )
 
     def wait(
@@ -637,7 +737,7 @@ class PcmkShortcuts():
                 ),
                 stderr=stderr,
                 returncode=returncode,
-            )
+            ),
         )
 
     def can_wait(
@@ -650,14 +750,15 @@ class PcmkShortcuts():
         string before -- key of call before which this new call is to be placed
         """
         self.__calls.place(
-            name,
-            RunnerCall("crm_resource -?", stdout=stdout),
-            before=before
+            name, RunnerCall("crm_resource -?", stdout=stdout), before=before
         )
 
     def verify(
-        self, name="runner.pcmk.verify", cib_tempfile=None, stderr=None,
-        verbose=False
+        self,
+        name="runner.pcmk.verify",
+        cib_tempfile=None,
+        stderr=None,
+        verbose=False,
     ):
         """
         Create call that checks that wait for idle is supported
@@ -670,8 +771,9 @@ class PcmkShortcuts():
             RunnerCall(
                 "crm_verify{0} {1}".format(
                     " -V -V" if verbose else "",
-                    "--xml-file {0}".format(cib_tempfile) if cib_tempfile
-                        else "--live-check"
+                    "--xml-file {0}".format(cib_tempfile)
+                    if cib_tempfile
+                    else "--live-check",
                 ),
                 stderr=("" if stderr is None else stderr),
                 returncode=(0 if stderr is None else 55),
@@ -679,8 +781,11 @@ class PcmkShortcuts():
         )
 
     def remove_node(
-        self, node_name,
-        stderr="", returncode=0, name="runner.pcmk.remove_node",
+        self,
+        node_name,
+        stderr="",
+        returncode=0,
+        name="runner.pcmk.remove_node",
     ):
         self.__calls.place(
             name,
@@ -692,11 +797,16 @@ class PcmkShortcuts():
         )
 
     def simulate_cib(
-        self, new_cib_filepath, transitions_filepath,
-        cib_modifiers=None, cib_load_name="runner.cib.load",
-        stdout="", stderr="", returncode=0,
+        self,
+        new_cib_filepath,
+        transitions_filepath,
+        cib_modifiers=None,
+        cib_load_name="runner.cib.load",
+        stdout="",
+        stderr="",
+        returncode=0,
         name="runner.pcmk.simulate_cib",
-        **modifier_shortcuts
+        **modifier_shortcuts,
     ):
         """
         Create a call for simulating effects of cib changes
@@ -721,12 +831,15 @@ class PcmkShortcuts():
         cib_xml = modify_cib(
             self.__calls.get(cib_load_name).stdout,
             cib_modifiers,
-            **modifier_shortcuts
+            **modifier_shortcuts,
         )
         cmd = [
-            "crm_simulate", "--simulate",
-            "--save-output", new_cib_filepath,
-            "--save-graph", transitions_filepath,
+            "crm_simulate",
+            "--simulate",
+            "--save-output",
+            new_cib_filepath,
+            "--save-graph",
+            transitions_filepath,
             "--xml-pipe",
         ]
         self.__calls.place(
