@@ -2,6 +2,7 @@ from pcs_test.tools.command_env.mock_runner import Call as RunnerCall
 
 from pcs import settings
 
+
 class SbdShortcuts:
     def __init__(self, calls):
         self.__calls = calls
@@ -13,7 +14,7 @@ class SbdShortcuts:
         stderr="",
         returncode=0,
         instead=None,
-        before=None
+        before=None,
     ):
         self.__calls.place(
             name,
@@ -24,5 +25,5 @@ class SbdShortcuts:
                 returncode=returncode,
             ),
             before=before,
-            instead=instead
+            instead=instead,
         )
