@@ -4,13 +4,18 @@ from pcs_test.tools.command_env.mock_runner import Call as RunnerCall
 
 from pcs import settings
 
+
 class SystemctlShortcuts:
     def __init__(self, calls):
         self.__calls = calls
 
     def disable(
-        self, service, name="runner.systemctl.disable",
-        stdout="", stderr="", returncode=0
+        self,
+        service,
+        name="runner.systemctl.disable",
+        stdout="",
+        stderr="",
+        returncode=0,
     ):
         self.__calls.place(
             name,
@@ -19,12 +24,16 @@ class SystemctlShortcuts:
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
-            )
+            ),
         )
 
     def enable(
-        self, service, name="runner.systemctl.enable",
-        stdout="", stderr="", returncode=0
+        self,
+        service,
+        name="runner.systemctl.enable",
+        stdout="",
+        stderr="",
+        returncode=0,
     ):
         self.__calls.place(
             name,
@@ -33,12 +42,16 @@ class SystemctlShortcuts:
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
-            )
+            ),
         )
 
     def start(
-        self, service, name="runner.systemctl.start",
-        stdout="", stderr="", returncode=0
+        self,
+        service,
+        name="runner.systemctl.start",
+        stdout="",
+        stderr="",
+        returncode=0,
     ):
         self.__calls.place(
             name,
@@ -47,12 +60,16 @@ class SystemctlShortcuts:
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
-            )
+            ),
         )
 
     def stop(
-        self, service, name="runner.systemctl.stop",
-        stdout="", stderr="", returncode=0
+        self,
+        service,
+        name="runner.systemctl.stop",
+        stdout="",
+        stderr="",
+        returncode=0,
     ):
         self.__calls.place(
             name,
@@ -61,61 +78,54 @@ class SystemctlShortcuts:
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
-            )
+            ),
         )
 
     def is_active(
         self, service, name="runner_systemctl.is_active", is_active=True
     ):
-        args = dict(
-            stdout="unknown\n",
-            returncode=3,
-        )
+        args = dict(stdout="unknown\n", returncode=3,)
         if is_active:
-            args = dict(
-                stdout="active\n",
-                returncode=0,
-            )
+            args = dict(stdout="active\n", returncode=0,)
         self.__calls.place(
             name,
             RunnerCall(
                 "{bin_path} is-active {service}.service".format(
-                    bin_path=settings.systemctl_binary,
-                    service=service,
+                    bin_path=settings.systemctl_binary, service=service,
                 ),
-                **args
-            )
+                **args,
+            ),
         )
 
     def is_enabled(
-        self, service, is_enabled=True,
-        name="runner_systemctl.is_enabled", before=None, instead=None
+        self,
+        service,
+        is_enabled=True,
+        name="runner_systemctl.is_enabled",
+        before=None,
+        instead=None,
     ):
-        args = dict(
-            stdout="disabled\n",
-            returncode=1,
-        )
+        args = dict(stdout="disabled\n", returncode=1,)
         if is_enabled:
-            args = dict(
-                stdout="enabled\n",
-                returncode=0,
-            )
+            args = dict(stdout="enabled\n", returncode=0,)
         self.__calls.place(
             name,
             RunnerCall(
                 "{bin_path} is-enabled {service}.service".format(
-                    bin_path=settings.systemctl_binary,
-                    service=service,
+                    bin_path=settings.systemctl_binary, service=service,
                 ),
-                **args
+                **args,
             ),
             before=before,
-            instead=instead
+            instead=instead,
         )
 
     def list_unit_files(
-        self, unit_file_states,
-        name="runner_systemctl.list_unit_files", before=None, instead=None
+        self,
+        unit_file_states,
+        name="runner_systemctl.list_unit_files",
+        before=None,
+        instead=None,
     ):
         if not unit_file_states:
             output = dedent(
@@ -132,23 +142,22 @@ class SystemctlShortcuts:
             lines = (
                 [
                     pattern.format(
-                        unit="UNIT FILE", unit_len=unit_len,
-                        state="STATE", state_len=state_len
+                        unit="UNIT FILE",
+                        unit_len=unit_len,
+                        state="STATE",
+                        state_len=state_len,
                     )
                 ]
-                +
-                [
+                + [
                     pattern.format(
-                        unit="{0}.service".format(unit), unit_len=unit_len,
-                        state=state, state_len=state_len
+                        unit="{0}.service".format(unit),
+                        unit_len=unit_len,
+                        state=state,
+                        state_len=state_len,
                     )
                     for unit, state in unit_file_states.items()
                 ]
-                +
-                [
-                    "",
-                    "{0} unit files listed.".format(len(unit_file_states))
-                ]
+                + ["", "{0} unit files listed.".format(len(unit_file_states))]
             )
             output = "\n".join(lines)
 
@@ -158,8 +167,8 @@ class SystemctlShortcuts:
                 "{bin_path} list-unit-files --full".format(
                     bin_path=settings.systemctl_binary
                 ),
-                stdout=output
+                stdout=output,
             ),
             before=before,
-            instead=instead
+            instead=instead,
         )
