@@ -27,6 +27,7 @@ def remote(params, request, auth_user)
       :status => method(:node_status),
       :status_all => method(:status_all),
       :cluster_status => method(:cluster_status_remote),
+      :cluster_status_plaintext => method(:cluster_status_plaintext),
       :auth => method(:auth),
       :check_auth => method(:check_auth),
       :cluster_setup => method(:cluster_setup),
@@ -165,31 +166,62 @@ def cluster_status_gui(auth_user, cluster_name, dont_update_config=false)
     return 403, 'Permission denied'
   end
 
+  if dont_update_config
+    return JSON.generate(status)
+  end
+
+  # source for :corosync_offline, etc... is result of command `pcs status nodes
+  # both` launched on one of cluster nodes.
   new_cluster_nodes = []
   new_cluster_nodes += status[:corosync_offline] if status[:corosync_offline]
   new_cluster_nodes += status[:corosync_online] if status[:corosync_online]
   new_cluster_nodes += status[:pacemaker_offline] if status[:pacemaker_offline]
   new_cluster_nodes += status[:pacemaker_online] if status[:pacemaker_online]
   new_cluster_nodes.uniq!
+  if new_cluster_nodes.length == 0
+    # We haven't got direct info about participating nodes from one of cluster
+    # nodes. But it does not mean that cluster does not exist - all nodes can
+    # be offline!
+    # So, we use nodes from :node_list. There is a set of nodes we have
+    # provided to `cluster_status_from_nodes` (i.e. from pcs_settings) minus
+    # nodes that reliably have said that they are in another cluster. If
+    # :node_list is empty it means that all nodes from pcs_settings have said
+    # that they are in another cluster and requested cluster should be removed
+    # from pcs_settings.
+    new_cluster_nodes = status[:node_list].map{|n| n[:name]}
+  end
+
+  config = PCSConfig.new(Cfgsync::PcsdSettings.from_file().text())
+
+  if config.cluster_nodes_equal?(cluster_name, new_cluster_nodes)
+    return JSON.generate(status)
+  end
+
+  _update_pcsd_settings(config, cluster_name, new_cluster_nodes)
 
   if new_cluster_nodes.length > 0
-    config = PCSConfig.new(Cfgsync::PcsdSettings.from_file().text())
-    if !(dont_update_config or config.cluster_nodes_equal?(cluster_name, new_cluster_nodes))
-      old_cluster_nodes = config.get_nodes(cluster_name)
-      $logger.info("Updating node list for: #{cluster_name} #{old_cluster_nodes}->#{new_cluster_nodes}")
-      config.update_cluster(cluster_name, new_cluster_nodes)
-      sync_config = Cfgsync::PcsdSettings.from_text(config.text())
-      # on version conflict just go on, config will be corrected eventually
-      # by displaying the cluster in the web UI
-      Cfgsync::save_sync_new_version(
-          sync_config, get_corosync_nodes_names(), $cluster_name, true
-      )
-      return cluster_status_gui(auth_user, cluster_name, true)
-    end
+    return cluster_status_gui(auth_user, cluster_name, true)
   end
   return JSON.generate(status)
 end
 
+def _update_pcsd_settings(config, cluster_name, new_nodes)
+  old_nodes = config.get_nodes(cluster_name)
+  
+  # removing log is embeded in config.update_cluster
+  $logger.info(
+    "Updating node list for: #{cluster_name} #{old_nodes}->#{new_nodes}"
+  )
+
+  config.update_cluster(cluster_name, new_nodes)
+  sync_config = Cfgsync::PcsdSettings.from_text(config.text())
+  # on version conflict just go on, config will be corrected eventually
+  # by displaying the cluster in the web UI
+  Cfgsync::save_sync_new_version(
+    sync_config, get_corosync_nodes_names(), $cluster_name, true
+  )
+end
+
 # get cluster status and return it to a remote gui or other client
 def cluster_status_remote(params, request, auth_user)
   if not allowed_for_local_cluster(auth_user, Permissions::READ)
@@ -219,6 +251,18 @@ def cluster_status_remote(params, request, auth_user)
   return JSON.generate(status)
 end
 
+# get cluster status in plaintext (over-the-network version of 'pcs status')
+def cluster_status_plaintext(params, request, auth_user)
+  if not allowed_for_local_cluster(auth_user, Permissions::READ)
+    return 403, 'Permission denied'
+  end
+  return pcs_internal_proxy(
+    auth_user,
+    params.fetch(:data_json, ""),
+    "status.full_cluster_status_plaintext"
+  )
+end
+
 def cluster_start(params, request, auth_user)
   if params[:name]
     code, response = send_request_with_token(
@@ -444,7 +488,11 @@ def get_corosync_conf_remote(params, request, auth_user)
   if not allowed_for_local_cluster(auth_user, Permissions::READ)
     return 403, 'Permission denied'
   end
-  return get_corosync_conf()
+  begin
+    return get_corosync_conf()
+  rescue
+    return 400, 'Unable to read corosync.conf'
+  end
 end
 
 # deprecated, use /remote/put_file (note that put_file doesn't support backup
@@ -610,8 +658,8 @@ def set_certs(params, request, auth_user)
     rescue => e
       # clean the files if we ended in the middle
       # the files will be regenerated on next pcsd start
-      FileUtils.rm(CRT_FILE, {:force => true})
-      FileUtils.rm(KEY_FILE, {:force => true})
+      FileUtils.rm(CRT_FILE, :force => true)
+      FileUtils.rm(KEY_FILE, :force => true)
       return [400, "cannot save ssl files: #{e}"]
     end
   end
@@ -921,7 +969,8 @@ def status_all(params, request, auth_user, nodes=[], dont_update_config=false)
   threads = []
   forbidden_nodes = {}
   nodes.each {|node|
-    threads << Thread.new {
+    threads << Thread.new(Thread.current[:pcsd_logger_container]) { |logger|
+      Thread.current[:pcsd_logger_container] = logger
       code, response = send_request_with_token(auth_user, node, 'status')
       if 403 == code
         forbidden_nodes[node] = true
@@ -971,13 +1020,23 @@ def status_all(params, request, auth_user, nodes=[], dont_update_config=false)
   return JSON.generate(final_response)
 end
 
+def imported_cluster_list(params, request, auth_user)
+  config = PCSConfig.new(Cfgsync::PcsdSettings.from_file().text())
+  imported_clusters = {"cluster_list" => []}
+  config.clusters.each { |cluster|
+    imported_clusters["cluster_list"] << { "name": cluster.name }
+  }
+  return JSON.generate(imported_clusters)
+end
+
 def clusters_overview(params, request, auth_user)
   cluster_map = {}
   forbidden_clusters = {}
   threads = []
   config = PCSConfig.new(Cfgsync::PcsdSettings.from_file().text())
   config.clusters.each { |cluster|
-    threads << Thread.new {
+    threads << Thread.new(Thread.current[:pcsd_logger_container]) { |logger|
+      Thread.current[:pcsd_logger_container] = logger
       cluster_map[cluster.name] = {
         'cluster_name' => cluster.name,
         'error_list' => [
@@ -1189,26 +1248,20 @@ def resource_stop(params, request, auth_user)
 end
 
 def resource_cleanup(params, request, auth_user)
-  if not allowed_for_local_cluster(auth_user, Permissions::WRITE)
-    return 403, 'Permission denied'
-  end
-  stdout, stderr, retval = run_cmd(
-    auth_user, PCS, "resource", "cleanup", params[:resource]
-  )
-  if retval == 0
-    return JSON.generate({"success" => "true"})
-  else
-    return JSON.generate({"error" => "true", "stdout" => stdout, "stderror" => stderr})
-  end
+  return _resource_cleanup_refresh("cleanup", params, request, auth_user)
 end
 
 def resource_refresh(params, request, auth_user)
+  return _resource_cleanup_refresh("refresh", params, request, auth_user)
+end
+
+def _resource_cleanup_refresh(action, params, request, auth_user)
   if not allowed_for_local_cluster(auth_user, Permissions::WRITE)
     return 403, 'Permission denied'
   end
-  cmd = [PCS, "resource", "refresh", params[:resource]]
-  if params[:full] == '1'
-    cmd << "--full"
+  cmd = [PCS, "resource", action, params[:resource]]
+  if params[:strict] == '1'
+    cmd << "--force"
   end
   stdout, stderr, retval = run_cmd(auth_user, *cmd)
   if retval == 0
